<!DOCTYPE html>
{% load i18n staticfiles %}
<html>
<head>
    <title>{% block title %}{% trans "Mobile App Distribution" %}{% endblock %}</title>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width; initial-scale=1.0;">
    <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/foundation.min.css' %}">
    <script src="{% static 'django_mobile_app_distribution/js/vendor/modernizr.js' %}"></script>
    {% block extra_style %}{% endblock %}
    {% block extra_script %}{% endblock %}
    {% block extra_head %}{% endblock %}
    <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/app.css' %}">
</head>
<body>
{% block content %}{% endblock %}
<script src="{% static 'django_mobile_app_distribution/js/vendor/jquery.js' %}"></script>
<script src="{% static 'django_mobile_app_distribution/js/foundation/foundation.min.js' %}"></script>
<script>
    $(document).foundation();
</script>
</body>
</html>