{% extends "django_mobile_app_distribution/base.html" %}
{% load i18n staticfiles %}
{% load url from future %}
{% block title %}{% trans "logged out successfully" %}{% endblock %}
{% block content %}

    <div class="row">
        <div class="small-12 columns">
            <h3>{% trans 'You were logged out successfully.' %}</h3>
        </div>
    </div>
    <div class="row">
        <div class="small-12 columns">
            <a class="button expand" href="{% url 'auth_login' %}">{%  trans 'login' %}</a>
        </div>
    </div>


{% endblock %}