# -*- coding: utf-8 -*-
from __future__ import unicode_literals

class MobileAppDistributionConfigurationException(Exception):
    """A misconfiguration within the Django Mobile App Distribution settings is causing invalid states"""
    pass
