{% extends "django_mobile_app_distribution/base.html" %}
{% load i18n staticfiles %}
{% load url from future %}
{% block title %}{% trans "customer login" %}{% endblock %}
{% block content %}

    <form method="post" action="{% url 'django.contrib.auth.views.login' %}">{% csrf_token %}
        <fieldset>

            <div class="row collapse center">
                <div class="small-5 columns">
                    <span class="prefix">{{ form.username.label }}</span>
                </div>
                <div class="small-7 columns">
                    {{ form.username }}
                </div>
            </div>

            <div class="row collapse">
                <div class="small-5 columns">
                    <span class="prefix">{{ form.password.label }}</span>
                </div>
                <div class="small-7 columns">
                    {{ form.password }}
                </div>
            </div>

            <div class="row collapse">
                <div class="small-12 text-center columns">
                    {% if form.errors %}
                        <small class="error">{% trans "invalid login credentials" %}</small>
                    {% endif %}
                </div>
            </div>

            <div class="row collapse">
                <div class="small-12 columns">
                    <input type="submit" class="button expand" value="{% trans 'login' %}" />
                </div>
            </div>
            <input type="hidden" name="next" value="{{ next }}" />

        </fieldset>
    </form>
{% endblock %}
